@@ -218,10 +218,7 @@ pub trait Info {
     /// This method contains unsafe code.
     fn network_enabled(&self) -> bool {
         let res = unsafe { proj_context_is_network_enabled(self.ctx()) };
-        match res {
-            1 => true,
-            _ => false,
-        }
+        matches!(res, 1)
     }
 
     /// Get the URL endpoint to query for remote grids
@@ -370,7 +367,7 @@ impl ProjBuilder {
     /// This method contains unsafe code.
     pub fn proj(mut self, definition: &str) -> Option<Proj> {
         let ctx = unsafe { std::mem::replace(&mut self.ctx, proj_context_create()) };
-        Some(transform_string(ctx, definition)?)
+        transform_string(ctx, definition)
     }
 
     /// Try to create a transformation object that is a pipeline between two known coordinate reference systems.
@@ -413,7 +410,7 @@ impl ProjBuilder {
     /// This method contains unsafe code.
     pub fn proj_known_crs(mut self, from: &str, to: &str, area: Option<Area>) -> Option<Proj> {
         let ctx = unsafe { std::mem::replace(&mut self.ctx, proj_context_create()) };
-        Some(transform_epsg(ctx, from, to, area)?)
+        transform_epsg(ctx, from, to, area)
     }
 }
 
@@ -448,7 +445,7 @@ impl Proj {
     // and vice versa, or using PJ_XY for conversion operations
     pub fn new(definition: &str) -> Option<Proj> {
         let ctx = unsafe { proj_context_create() };
-        Some(transform_string(ctx, definition)?)
+        transform_string(ctx, definition)
     }
 
     /// Try to create a new transformation object that is a pipeline between two known coordinate reference systems.
@@ -491,7 +488,7 @@ impl Proj {
     /// This method contains unsafe code.
     pub fn new_known_crs(from: &str, to: &str, area: Option<Area>) -> Option<Proj> {
         let ctx = unsafe { proj_context_create() };
-        Some(transform_epsg(ctx, from, to, area)?)
+        transform_epsg(ctx, from, to, area)
     }
 
     /// Set the bounding box of the area of use
@@ -911,6 +908,8 @@ impl Drop for ProjBuilder {
 
 #[cfg(test)]
 mod test {
+    use crate::proj;
+
     use super::*;
 
     #[derive(Debug)]
@@ -1036,8 +1035,8 @@ mod test {
         let t = proj
             .convert(MyPoint::new(4760096.421921, 3744293.729449))
             .unwrap();
-        assert_relative_eq!(t.x(), 1450880.2910605003);
-        assert_relative_eq!(t.y(), 1141263.0111604529);
+        assert_relative_eq!(t.x(), 1450880.2910605022);
+        assert_relative_eq!(t.y(), 1141263.0111604782);
     }
     #[test]
     // Carry out a projection from geodetic coordinates
@@ -1089,22 +1088,23 @@ mod test {
     #[test]
     // Carry out a conversion from NAD83 feet (EPSG 2230) to NAD83 metres (EPSG 26946)
     fn test_conversion() {
-        let nad83_m = Proj::new("
-            +proj=pipeline
-            +step +inv +proj=lcc +lat_1=33.88333333333333
-            +lat_2=32.78333333333333 +lat_0=32.16666666666666
-            +lon_0=-116.25 +x_0=2000000.0001016 +y_0=500000.0001016001 +ellps=GRS80
-            +towgs84=0,0,0,0,0,0,0 +units=us-ft +no_defs
-            +step +proj=lcc +lat_1=33.88333333333333 +lat_2=32.78333333333333 +lat_0=32.16666666666666
-            +lon_0=-116.25 +x_0=2000000 +y_0=500000
-            +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs
-        ").unwrap();
+        // Generated by PROJ by specifying "from" and "to" EPSG codes and calling def()
+        let projstring = "
+            proj=pipeline step proj=unitconvert xy_in=us-ft 
+            xy_out=m step inv proj=lcc lat_0=32.1666666666667 
+            lon_0=-116.25 lat_1=33.8833333333333 lat_2=32.7833333333333 
+            x_0=2000000.0001016 y_0=500000.0001016 ellps=GRS80 step proj=lcc lat_0=32.1666666666667 
+            lon_0=-116.25 lat_1=33.8833333333333 lat_2=32.7833333333333 x_0=2000000 y_0=500000 
+            ellps=GRS80
+            ";
+        let nad83_m = Proj::new(projstring).unwrap();
+        println!("{:?}", nad83_m.def().unwrap());
         // Presidio, San Francisco
         let t = nad83_m
             .convert(MyPoint::new(4760096.421921, 3744293.729449))
             .unwrap();
-        assert_relative_eq!(t.x(), 1450880.2910605003);
-        assert_relative_eq!(t.y(), 1141263.01116045);
+        assert_relative_eq!(t.x(), 1450880.2910605022);
+        assert_relative_eq!(t.y(), 1141263.0111604782);
     }
     #[test]
     // Test that instantiation fails wth bad proj string input
@@ -1122,7 +1122,7 @@ mod test {
             .convert(MyPoint::new(4760096.421921, 3744293.729449))
             .unwrap_err();
         assert_eq!(
-            "The conversion failed with the following error: latitude or longitude exceeded limits",
+            "The conversion failed with the following error: Invalid coordinate",
             err.to_string()
         );
     }
@@ -1159,8 +1159,8 @@ mod test {
             MyPoint::new(4760197.421921, 3744394.729449),
         ];
         ft_to_m.convert_array(&mut v).unwrap();
-        assert_relative_eq!(v[0].x(), 1450880.2910605003f64);
-        assert_relative_eq!(v[1].y(), 1141293.7960220198);
+        assert_relative_eq!(v[0].x(), 1450880.2910605022f64);
+        assert_relative_eq!(v[1].y(), 1141293.7960220438);
     }
 
     #[test]
@@ -1174,7 +1174,7 @@ mod test {
         let usa_m = MyPoint::new(-115.797615, 37.2647978);
         let usa_ft = to_feet.convert(usa_m).unwrap();
         assert_eq!(6693625.67217475, usa_ft.x());
-        assert_eq!(3497301.5918027186, usa_ft.y());
+        assert_eq!(3497301.5918027232, usa_ft.y());
     }
 
     #[test]
@@ -1186,7 +1186,7 @@ mod test {
         assert_eq!(area.west, -35.58);
         assert_eq!(area.south, 24.6);
         assert_eq!(area.east, 44.83);
-        assert_eq!(area.north, 84.17);
+        assert_eq!(area.north, 84.73);
         assert!(name.contains("Europe"));
     }
 }
